from icu import UnicodeString, Normalizer2, Transliterator

def to_latin(string):
    ustring = UnicodeString(string)
    nfc = Normalizer2.getNFCInstance()
    ustring = nfc.normalize(ustring)

    trans = Transliterator.createFromRules("",
                                           "$wb = [^[:Letter:]] ;"
                                           ";"
                                           # е
                                           "$wb { е } $wb > e ;"
                                           "$wb { Е } $wb > E ;"
                                           "$wb { е > e ;"
                                           "$wb { Е > | E ;"
                                           "[ьЬ] { е > ye ;"
                                           "[ьЬ] { Е > YE ;"
                                           "[ъЪ] { е > qe ;"
                                           "[ъЪ] { Е > QE ;"
                                           "е > e ;"
                                           "Е > E ;"
                                           # э
                                           "$wb { э } $wb > q ;"
                                           "$wb { Э } $wb > Q ;"
                                           "$wb { э > q ;"
                                           "$wb { Э > Q ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { э > е ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { Э > E ;"
                                           "э > q ;"
                                           "Э > Q ;"
                                           # ы
                                           "[жЖшШцЦйЙjJwWcCyY] { ы > i ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { Ы > I ;"
                                           "ы > qi ;"
                                           "Ы > QI ;"
                                           # ё
                                           "$wb { ё } $wb > yo ;"
                                           "$wb { Ё } $wb > YO ;"
                                           "$wb { ё > yo ;"
                                           "$wb { Ё } [[:Ll:]] > Yo ;"
                                           "$wb { Ё > YO ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { ё > o ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { Ё > O ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { ё > yo ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { Ё > YO ;"
                                           "[ъЪ] { ё > qo ;"
                                           "[ъЪ] { Ё > QO ;"
                                           "ё > ho ;"
                                           "Ё > HO ;"
                                           # ю
                                           "$wb { ю > yu ;"
                                           "$wb { Ю } [[:Ll:]] > Yu ;"
                                           "$wb { Ю > YU ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { ю > u ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { Ю > U ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { ю > yu ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { Ю > YU ;"
                                           "[ъЪ] { ю > qu ;"
                                           "[ъЪ] { Ю > QU ;"
                                           "ю > hu ;"
                                           "Ю > HU ;"
                                           # я
                                           "$wb { я > ya ;"
                                           "$wb { Я } [[:Ll:]] > Ya ;"
                                           "$wb { Я > YA ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { я > a ;"
                                           "[жЖшШцЦйЙjJwWcCyY] { Я > A ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { я > ya ;"
                                           "[уУеЕёЁыЫаАоОэЭяЯиИюЮьЬiIuUoOeEaAqQ] { Я > YA ;"
                                           "[ъЪ] { я > qa ;"
                                           "[ъЪ] { Я > QA ;"
                                           "я > ha ;"
                                           "Я > HA ;"
                                           # Буква и (э уже транслитерирована)
                                           "[qQ] { и > hi ;"
                                           "[qQ] { и > hi ;"
                                           "Q { И > HI ;"
                                           "q { И > hI ;"
                                           "ьи > yi ;"
                                           "Ьи > Yi ;"
                                           "ьИ > yI ;"
                                           "ЬИ > YI ;"
                                           "ъи > qi ;"
                                           "Ъи > qi ;"
                                           "ъИ > QI ;"
                                           "ЪИ > YI ;"
                                           "и > i ; И > I ;"
                                           # Буква а (э уже транслитерирована)
                                           "[qQ] { а > ha ;"
                                           "[qQ] { а > ha ;"
                                           "Q { А > HA ;"
                                           "q { А > hA ;"
                                           "ьа > ya ;"
                                           "Ьа > Ya ;"
                                           "ьА > yA ;"
                                           "ЬА > YA ;"
                                           "а > a ; А > A ;"
                                           # Буква о (э уже транслитерирована)
                                           "[qQ] { о > ho ;"
                                           "[qQ] { о > ho ;"
                                           "Q { О > HO ;"
                                           "q { О > hO ;"
                                           "ьо > yo ;"
                                           "Ьо > Yo ;"
                                           "ьО > yO ;"
                                           "ЬО > YO ;"
                                           "о > o ; О > O ;"
                                           # Буква у (э уже транслитерирована)
                                           "[qQ] { у > hu ;"
                                           "[qQ] { у > hu ;"
                                           "Q { У > HU ;"
                                           "q { У > hU ;"
                                           "ьу > yu ;"
                                           "Ьу > Yu ;"
                                           "ьУ > yU ;"
                                           "ЬУ > YU ;"
                                           "у > u ; У > U ;"
                                           # Согласные буквы
                                           "б > b ; Б > B ;"
                                           "в > v ; В > V ;"
                                           "г > g ; Г > G ;"
                                           "д > d ; Д > D ;"
                                           "ж > j ; Ж > J ;"
                                           "з > z ; З > Z ;"
                                           "й > y ; Й > Y ;"
                                           "к > k ; К > K ;"
                                           "л > l ; Л > L ;"
                                           "м > m ; М > M ;"
                                           "н > n ; Н > N ;"
                                           "п > p ; П > P ;"
                                           "р > r ; Р > R ;"
                                           "с > s ; С > S ;"
                                           "т > t ; Т > T ;"
                                           "ф > f ; Ф > F ;"
                                           "х > x ; Х > X ;"
                                           "ц > c ; Ц > C ;"
                                           "ч > ch ;"
                                           "$wb { Ч } [[:Ll:]] > Ch ;"
                                           "Ч > CH ;"
                                           "ш > w ; Ш > W ;"
                                           "щ > wh ;"
                                           "$wb { Щ } [[:Ll:]] > Wh ;"
                                           "Щ > WH ;"
                                           # Проход с начала, в строке незаменены остались только буквы ь и ъ
                                           ":: Any-Null ;"
                                           "ь } [yY] > ;"
                                           "Ь } [yY] > ;"
                                           "[cCwWjJhH] { ь > ;"
                                           "[cCwWjJhH] { Ь > ;"
                                           "ь > h ;"
                                           "Ь > H ;"
                                           "ъ > ;"
                                           "Ъ > ;"
                                           # Проход с начала
                                           ":: Any-Null ;"
                                           "h+ > h ;"
                                           "H+ > H ;"
                                           "[hH]+ > H ;"
                                           )
    ustring = trans.transliterate(ustring)
    return ustring
